==> haskell-regex-base-0.94.0.3-2.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-base
version:              0.94.0.3
visibility:           public
id:                   regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
key:                  regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           Andreas Abel
author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Common "Text.Regex.*" API for Regex matching
description:
    This package does not provide the ability to do regular expression matching.
    Instead, it provides the type classes that constitute the abstract API
    that is implemented by @regex-*@ backends such as:

    * <https://hackage.haskell.org/package/regex-posix regex-posix>

    * <https://hackage.haskell.org/package/regex-parsec regex-parsec>

    * <https://hackage.haskell.org/package/regex-dfa regex-dfa>

    * <https://hackage.haskell.org/package/regex-tdfa regex-tdfa>

    * <https://hackage.haskell.org/package/regex-pcre regex-pcre>

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  b7a66761a4c3917e338b2f8e6bf4e4d8
exposed:              True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike

hidden-modules:       Paths_regex_base
import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-base-0.94.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-base-0.94.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-base-0.94.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-base
hs-libraries:         HSregex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html:         /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-base-0.94.0.3-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-base
version:              0.94.0.3
visibility:           public
id:                   regex-base-0.94.0.3-2nKwTtnMBcoCMKi4tw1MOe
key:                  regex-base-0.94.0.3-2nKwTtnMBcoCMKi4tw1MOe
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           Andreas Abel
author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Common "Text.Regex.*" API for Regex matching
description:
    This package does not provide the ability to do regular expression matching.
    Instead, it provides the type classes that constitute the abstract API
    that is implemented by @regex-*@ backends such as:

    * <https://hackage.haskell.org/package/regex-posix regex-posix>

    * <https://hackage.haskell.org/package/regex-parsec regex-parsec>

    * <https://hackage.haskell.org/package/regex-dfa regex-dfa>

    * <https://hackage.haskell.org/package/regex-tdfa regex-tdfa>

    * <https://hackage.haskell.org/package/regex-pcre regex-pcre>

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  d53e0ce17c583effedbf49d576f06baf
exposed:              True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike

hidden-modules:       Paths_regex_base
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/regex-base-0.94.0.3
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/regex-base-0.94.0.3
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/regex-base-0.94.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-base
hs-libraries:         HSregex-base-0.94.0.3-2nKwTtnMBcoCMKi4tw1MOe
depends:
    array-0.5.8.0 base-4.18.3.0 bytestring-0.11.5.4 containers-0.6.7
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html:         /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
